aboutsummaryrefslogtreecommitdiffstats
path: root/resources/libraries/python
diff options
context:
space:
mode:
Diffstat (limited to 'resources/libraries/python')
-rw-r--r--resources/libraries/python/Adl.py (renamed from resources/libraries/python/Cop.py)42
1 files changed, 21 insertions, 21 deletions
diff --git a/resources/libraries/python/Cop.py b/resources/libraries/python/Adl.py
index 29530b1277..abb7e731f3 100644
--- a/resources/libraries/python/Cop.py
+++ b/resources/libraries/python/Adl.py
@@ -1,4 +1,4 @@
-# Copyright (c) 2019 Cisco and/or its affiliates.
+# Copyright (c) 2021 Cisco and/or its affiliates.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at:
@@ -11,57 +11,57 @@
# See the License for the specific language governing permissions and
# limitations under the License.
"""COP utilities library."""
from resources.libraries.python.PapiExecutor import PapiSocketExecutor
from resources.libraries.python.topology import Topology
-class Cop:
- """COP utilities."""
+class Adl:
+ """ADL utilities."""
@staticmethod
- def cop_add_whitelist_entry(
- node, interface, ip_version, fib_id, default_cop=0):
- """Add cop whitelisted entry.
+ def adl_add_allowlist_entry(
+ node, interface, ip_version, fib_id, default_adl=0):
+ """Add adl allowlisted entry.
- :param node: Node to add COP whitelist on.
- :param interface: Interface of the node where the COP is added.
+ :param node: Node to add ADL allowlist on.
+ :param interface: Interface of the node where the ADL is added.
:param ip_version: IP version. 'ip4' and 'ip6' are valid values.
:param fib_id: Specify the fib table ID.
- :param default_cop: 1 => enable non-ip4, non-ip6 filtration,
+ :param default_adl: 1 => enable non-ip4, non-ip6 filtration,
0 => disable it.
:type node: dict
:type interface: str
:type ip_version: str
:type fib_id: int
- :type default_cop: int
+ :type default_adl: int
:raises ValueError: If parameter 'ip_version' has incorrect value.
"""
if ip_version not in (u"ip4", u"ip6"):
raise ValueError(u"IP version is not in correct format")
- cmd = u"cop_whitelist_enable_disable"
- err_msg = f"Failed to add COP whitelist on interface {interface} " \
+ cmd = u"adl_allowlist_enable_disable"
+ err_msg = f"Failed to add ADL allowlist on interface {interface} " \
f"on host {node[u'host']}"
args = dict(
sw_if_index=Topology.get_interface_sw_index(node, interface),
fib_id=int(fib_id),
ip4=bool(ip_version == u"ip4"),
ip6=bool(ip_version == u"ip6"),
- default_cop=default_cop
+ default_adl=default_adl
)
with PapiSocketExecutor(node) as papi_exec:
papi_exec.add(cmd, **args).get_reply(err_msg)
@staticmethod
- def cop_interface_enable_or_disable(node, interface, state):
- """Enable or disable COP on the interface.
+ def adl_interface_enable_or_disable(node, interface, state):
+ """Enable or disable ADL on the interface.
- :param node: Node to add COP whitelist on.
- :param interface: Interface of the node where the COP is added.
- :param state: Enable or disable COP on the interface.
+ :param node: Node to add ADL allowlist on.
+ :param interface: Interface of the node where the ADL is added.
+ :param state: Enable or disable ADL on the interface.
:type node: dict
:type interface: str
:type state: str
@@ -73,8 +73,8 @@ class Cop:
else:
raise ValueError(u"Possible state values are 'enable' or 'disable'")
- cmd = u"cop_interface_enable_disable"
- err_msg = f"Failed to enable/disable COP on interface {interface} " \
+ cmd = u"adl_interface_enable_disable"
+ err_msg = f"Failed to enable/disable ADL on interface {interface} " \
f"on host {node[u'host']}"
args = dict(
sw_if_index=Topology.get_interface_sw_index(node, interface),
@@ -11,57 +11,57 @@
# See the License for the specific language governing permissions and
# limitations under the License.
-"""COP utilities library."""
+"""ADL utilities library."""
from resources.libraries.python.PapiExecutor import PapiSocketExecutor
from resources.libraries.python.topology import Topology